version 9
clear
capture log close
set matsize 500
set more off
set scheme s2manual

// asprvalue section

spex travel2
gen trainXhinc = hinc*train
gen busXhinc = hinc*bus
clogit choice time trainXhinc busXhinc train bus, group(id) nolog

asprvalue, x(time=240 180 300) base(car)

quietly asprvalue, x(hinc=40) rest(asmean) base(car) save
asprvalue, x(hinc=50) rest(asmean) base(car) diff

// brant section

use ordwarm2, clear
ologit warm yr89 male white age ed prst, nolog
brant
brant, detail

// case2alt section

spex wlsrnk, clear
label variable value1 "est"
label variable value2 "var"
label variable value3 "aut"
label variable value4 "sec"
case2alt, case(id) rank(value) alt(hashi haslo) casevars(fem hn) gen(rank) ///
 altnum(alt)

// countfit section

spex couart2, clear
countfit art fem mar kid5 phd ment, inf(ment fem) nbreg zinb nograph noprtable

// fitstat section

use binlfp2, clear
logit lfp k5 k618 age wc hc lwg inc, nolog
fitstat
logit lfp k5 k618 age wc hc lwg inc, nolog
quietly fitstat, saving(mod1)
gen age2 = age*age
logit lfp k5 age age2 wc inc, nolog
fitstat, using(mod1)

// leastlikely section

spex binlfp2, clear
logit lfp k5 k618 age wc hc lwg inc
leastlikely

spex nomocc2, clear
mlogit occ white ed exper
leastlikely white ed exper

// use regjob2, clear  regjob2 not available
// * regress
// regress job fem phd ment fel art cit
// listcoef, pv(.05)
// 
// use ordwarm2, clear
// ologit warm age ed prst male yr89 white, nolog
// listcoef age, std
// listcoef age
// listcoef age, rev
// 
// use nomocc2, clear
// mlogit occ white ed exp, nolog
// listcoef white, percent pv(.05)

// misschk section

spex gsskidvalue2
misschk female-income91, gen(m_) dummy
describe m_*

use nomocc2, clear
mlogit occ white ed exper
prchange
mlogplot white ed exper, dc std(0ss) min(-.5) max(.5)
mlogplot white ed exper, or std(0ss) min(-2.75) max(.5)
mlogplot white ed exper, or dchange std(0ss) base(4) min(-1.75) max(1.75)
matrix mnlsd = (2.946427, 13.95936, 2.946427, 13.95936)
global mnlname = "W_Educ W_Exper NW_Educ NW_Exper"
global mnlrefn = 5
global mnlcatnm = "Menial BlueC Craft WhiteC Prof"
matrix mnlbeta = (-.83075, -.92255, -.68761, -.41964 -.03380, -.3145,   ///
   -.00026, .00085 -.70126, -.56070, -.88250, -.53115 -.11084, -.02611, ///
   -.15979, -.05209 )
matrix mnlbeta = mnlbeta'
mlogplot, vars(W_Educ NW_Educ W_Exper NW_Exper) matrix ///
    std(ssss) note("Effects of Education")

//mlogtest section

use nomocc2, clear
mlogit occ white ed exper
set seed 131324
mlogtest, all

mlogtest, iia base

mlogtest, lr set(ed exper white ed white ed exper)

use ordwarm2, clear
ologit warm male white age ed prst if yr89==1, nolog
* set independent variables to mean in estimation sample
prvalue
* set independent variables to mean for all cases in memory
prvalue, all
* set male to 0, ed to 12, age to 30, everything else to mean
prvalue, x(male=0 ed=12 age=30) rest(mean)
* set male to 0, all others to mean for males
prvalue, x(male=0) rest(grmean)
* set male to 0, age to median, all others to mean
prvalue, x(male=0 age=median) rest(mean)
* set to statistics in full sample instead of estimation sample
prvalue, x(male=0 age=median) rest(mean) all

use binlfp2, clear
gen age2 = age*age
logit lfp k5 k618 age age2 wc hc lwg inc, nolog
prvalue, x(age 20 age2 400) rest(mean) brief
praccum, saving(m_age) xis(20)
prvalue, x(age 25 age2 625) rest(mean) brief
praccum, using(m_age) xis(25)
prvalue, x(age 30 age2 900) rest(mean) brief
praccum, using(m_age) xis(30)
prvalue, x(age 35 age2 1225) rest(mean) brief
praccum, using(m_age) xis(35)
prvalue, x(age 40 age2 1600) rest(mean) brief
praccum, using(m_age) xis(40)
prvalue, x(age 45 age2 2025) rest(mean) brief
praccum, using(m_age) xis(45)
prvalue, x(age 50 age2 2500) rest(mean) brief
praccum, using(m_age) xis(50)
prvalue, x(age 55 age2 3025) rest(mean) brief
praccum, using(m_age) xis(55)
prvalue, x(age 60 age2 3600) rest(mean) brief
praccum, using(m_age) xis(60) gen(agsq)
* these variables were created
list agsq* in 1/9

* estimate the model
use ordwarm2, clear
ologit warm male white age ed prst if yr89==1, nolog
* holding all variables to the estimation sample means
prchange age white
* specific set of base values
prchange, x(male=1 white=1 age=30) rest(median)

// use ordwarm2, clear
// prcounts znb
// summarize znb*
// poisson art fem mar kid5 phd ment
// prcounts prm, max(8) plot
// summarize prm*

use ordwarm2, clear
oprobit warm yr89 male white age ed prst, nolog
* predict probabilities as age changes from 20 to 80
prgen age, f(20) t(80) gen(wrm)
list wrmx wrmp1 wrmp2 wrmp3 wrmp4 in 1/11
prgen age, x(male=1) rest(grmean) f(20) t(80) gen(mal)

use binlfp2, clear
probit lfp k5 k618 age wc hc lwg inc, nolog
prtab wc hc

use ordwarm2, clear
ologit warm yr89 male white age ed prst, nolog
prtab male white, x(prst=min)

use couart2, clear
poisson art fem mar kid5 phd ment, nolog
prtab fem mar
prtab fem mar, outcome(0)

// prvalue section

use ordwarm2, clear
oprobit warm yr89 male white age ed prst, nolog
* by default, hold all independent variables to their means
prvalue
*to compute all variables at their minimum
prvalue, rest(min)
* predictions for white females, with other variables at the median
prvalue, x(white=1 male=0) rest(median)
* or with other variables at median for white females
prvalue, x(white=1 male=0) rest(grmedian)
* to compare predictions for males and females
prvalue, x(male=0) save
prvalue, x(male=1) diff

// wlsrnk section

use wlsrnk, clear
describe
summarize
